==> llvm-toolchain-3.6_3.6.orig-clang.tar.bz2: clang_3.6~+final/test/SemaObjC/objc-dictionary-literal.m <==
// RUN: %clang_cc1  -fsyntax-only -verify %s
// rdar://11062080
// RUN: %clang_cc1  -fsyntax-only -triple i386-apple-macosx10.9.0 -fobjc-runtime=macosx-fragile-10.9.0 -fobjc-subscripting-legacy-runtime -verify %s
// rdar://15363492

#define nil ((void *)0)

@interface NSNumber
+ (NSNumber *)numberWithChar:(char)value;
+ (NSNumber *)numberWithInt:(int)value;
@end

@protocol NSCopying @end
typedef unsigned long NSUInteger;
typedef long NSInteger;

@interface NSDictionary
+ (id)dictionaryWithObjects:(const id [])objects forKeys:(const id <NSCopying> [])keys count:(NSUInteger)cnt;
- (void)setObject:(id)object forKeyedSubscript:(id)key;
- (id)objectForKeyedSubscript:(id)key;
@end

@interface NSString<NSCopying>
@end

@interface NSArray
- (id)objectAtIndexedSubscript:(NSInteger)index;
- (void)setObject:(id)object atIndexedSubscript:(NSInteger)index;
@end

void *pvoid;
int main() {
	NSDictionary *dict = @{ @"name":@666 };
        dict[@"name"] = @666;

        dict["name"] = @666; // expected-error {{indexing expression is invalid because subscript type 'char *' is not an Objective-C pointer}}

        // rdar://18254621
        [@{@"foo" : @"bar"} objectForKeyedSubscript:nil];
        (void)@{@"foo" : @"bar"}[nil];
        [@{@"foo" : @"bar"} objectForKeyedSubscript:pvoid];
        (void)@{@"foo" : @"bar"}[pvoid];

	[@{@"foo" : @"bar"} setObject:nil forKeyedSubscript:@"gorf"];
        @{@"foo" : @"bar"}[nil] = @"gorf";
	[@{@"foo" : @"bar"} setObject:pvoid forKeyedSubscript:@"gorf"];
        @{@"foo" : @"bar"}[pvoid] = @"gorf";

	return 0;
}

==> llvm-toolchain-3.7_3.7.1.orig-clang.tar.bz2: clang_3.7.1~+final/test/SemaObjC/objc-dictionary-literal.m <==
// RUN: %clang_cc1  -fsyntax-only -verify %s
// rdar://11062080
// RUN: %clang_cc1  -fsyntax-only -triple i386-apple-macosx10.9.0 -fobjc-runtime=macosx-fragile-10.9.0 -fobjc-subscripting-legacy-runtime -verify %s
// rdar://15363492

#define nil ((void *)0)

void checkNSDictionaryUnavailableDiagnostic() {
  id key;
  id value;
  id dict = @{ key : value }; // expected-error {{NSDictionary must be available to use Objective-C dictionary literals}}
}

@class NSDictionary;

void checkNSDictionaryFDDiagnostic() {
  id key;
  id value;
  id dic = @{ key : value }; // expected-error {{declaration of 'dictionaryWithObjects:forKeys:count:' is missing in NSDictionary class}}
}

@interface NSNumber
+ (NSNumber *)numberWithChar:(char)value;
+ (NSNumber *)numberWithInt:(int)value;
@end

@protocol NSCopying @end
typedef unsigned long NSUInteger;
typedef long NSInteger;

@interface NSDictionary
+ (id)dictionaryWithObjects:(const id [])objects forKeys:(const id <NSCopying> [])keys count:(NSUInteger)cnt;
- (void)setObject:(id)object forKeyedSubscript:(id)key;
- (id)objectForKeyedSubscript:(id)key;
@end

@interface NSString<NSCopying>
@end

@interface NSArray
- (id)objectAtIndexedSubscript:(NSInteger)index;
- (void)setObject:(id)object atIndexedSubscript:(NSInteger)index;
@end

void *pvoid;
int main() {
	NSDictionary *dict = @{ @"name":@666 };
        dict[@"name"] = @666;

        dict["name"] = @666; // expected-error {{indexing expression is invalid because subscript type 'char *' is not an Objective-C pointer}}

        // rdar://18254621
        [@{@"foo" : @"bar"} objectForKeyedSubscript:nil];
        (void)@{@"foo" : @"bar"}[nil];
        [@{@"foo" : @"bar"} objectForKeyedSubscript:pvoid];
        (void)@{@"foo" : @"bar"}[pvoid];

	[@{@"foo" : @"bar"} setObject:nil forKeyedSubscript:@"gorf"];
        @{@"foo" : @"bar"}[nil] = @"gorf";
	[@{@"foo" : @"bar"} setObject:pvoid forKeyedSubscript:@"gorf"];
        @{@"foo" : @"bar"}[pvoid] = @"gorf";

	return 0;
}
